Name:		voms-api-java
Version:	3.0.3
Release:	1%{?dist}
Summary:	Virtual Organization Membership Service Java API

Group:		Development/Libraries
License:	ASL 2.0
URL:		https://wiki.italiangrid.it/VOMS
Source0:	https://github.com/italiangrid/%{name}/archive/%{version}.tar.gz
#		Patch for bouncycastle 1.47+ (Fedora 21+, EPEL 7+)
Patch0:		%{name}-bc147.patch
#		Disable tests that fail outside the Central European time zone
#		https://github.com/italiangrid/voms-api-java/issues/8
Patch1:		%{name}-timezone-dep-test.patch
BuildArch:	noarch

BuildRequires:	maven-local
BuildRequires:	mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:	mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:	mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:	mvn(org.apache.maven.plugins:maven-release-plugin)

BuildRequires:	mvn(eu.eu-emi.security:canl)
%if %{?fedora}%{!?fedora:0} >= 21 || %{?rhel}%{!?rhel:0} >= 7
BuildRequires:	mvn(org.bouncycastle:bcpkix-jdk15on)
%else
BuildRequires:	mvn(org.bouncycastle:bcmail-jdk16)
%endif

BuildRequires:	mvn(junit:junit)
%if %{?fedora}%{!?fedora:0}
# Missing stuff in EPEL (mostly test frameworks)
BuildRequires:	mvn(com.mycila.maven-license-plugin:maven-license-plugin)
BuildRequires:	mvn(org.codehaus.mojo:cobertura-maven-plugin)
BuildRequires:	mvn(org.mockito:mockito-core)
BuildRequires:	mvn(net.jcip:jcip-annotations)
%endif

%description
The Virtual Organization Membership Service (VOMS) is an attribute authority
which serves as central repository for VO user authorization information,
providing support for sorting users into group hierarchies, keeping track of
their roles and other attributes in order to issue trusted attribute
certificates and SAML assertions used in the Grid environment for
authorization purposes.

This package provides a java client API for VOMS.

%package javadoc
Summary:	Virtual Organization Membership Service Java API Documentation
Group:		Documentation
Provides:	vomsjapi-javadoc = %{version}-%{release}
Obsoletes:	vomsjapi-javadoc < 2.0.7

%description javadoc
Virtual Organization Membership Service (VOMS) Java API Documentation.

%prep
%setup -q

%if %{?fedora}%{!?fedora:0} >= 21 || %{?rhel}%{!?rhel:0} >= 7
%patch0 -p1
%endif
%patch1 -p1

%if %{?fedora}%{!?fedora:0}
%pom_xpath_inject "pom:project/pom:build/pom:plugins/pom:plugin[pom:groupId='com.mycila.maven-license-plugin']/pom:configuration/pom:excludes" "<exclude>.xmvn/**</exclude>"
%else
# Missing stuff in EPEL (mostly test frameworks)
%pom_remove_plugin com.mycila.maven-license-plugin:maven-license-plugin
%pom_remove_plugin org.codehaus.mojo:cobertura-maven-plugin
%pom_remove_dep net.jcip:jcip-annotations
%pom_remove_dep org.mockito:mockito-core
%endif

%build
%if %{?fedora}%{!?fedora:0}
%mvn_build
%else
# Can not run tests in EPEL due to missing test frameworks
%mvn_build -f
%endif

%install
%mvn_install -J target/site/javadoc/apidocs

%files -f .mfiles
%dir %{_javadir}/%{name}
%doc AUTHORS LICENSE README.md

%files javadoc -f .mfiles-javadoc
%doc LICENSE

%changelog
* Thu Jun 26 2014 Mattias Ellert <mattias.ellert@fysast.uu.se> - 3.0.3-1
- Update to version 3.0.3

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Mar 10 2014 Mattias Ellert <mattias.ellert@fysast.uu.se> - 3.0.2-2
- Disable tests that fail outside the Central European time zone

* Sun Mar 09 2014 Mattias Ellert <mattias.ellert@fysast.uu.se> - 3.0.2-1
- Update to version 3
- Apply patch for bouncycastle 1.47+ on Fedora 21+ and EPEL 7+
- Convert to using xmvn

* Mon Oct 14 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.10-4
- Disable CRL tests (the CRL in the sources has expired)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Feb 12 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.10-2
- Add BR on maven-surefire-provider-junit

* Mon Feb 11 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.10-1
- Update to version 2.0.10

* Wed Feb 06 2013 Java SIG <java-devel@lists.fedoraproject.org> - 2.0.9-3
- Update for https://fedoraproject.org/wiki/Fedora_19_Maven_Rebuild
- Replace maven BuildRequires with maven-local

* Sun Dec 02 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.9-2
- Correct runtime requires and URL tag

* Thu Nov 29 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.9-1
- Update to version 2.0.9

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 24 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.8-1
- Update to version 2.0.8 (EMI 2 version)

* Mon Apr 23 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.7-2
- Fix compatibility maven fragment

* Tue Mar 20 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.7-1
- The Java API is now a separate source tree from the rest of voms
